<?php
/**
 * The template for adding Hero Content Settings in Customizer
 *
 * @package Decree Pro
 */

$wp_customize->add_section( 'decree_hero_content', array(
	'panel' => 'decree_theme_options',
	'title' => esc_html__( 'Hero Content', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[hero_content_option]', array(
	'default'           => $defaults['hero_content_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[hero_content_option]', array(
	'choices'  => decree_section_visibility_options(),
	'label'    => esc_html__( 'Enable on', 'decree-pro' ),
	'section'  => 'decree_hero_content',
	'settings' => 'decree_theme_options[hero_content_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[hero_content_type]', array(
	'default'           => $defaults['hero_content_type'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[hero_content_type]', array(
	'active_callback' => 'decree_is_hero_content_active',
	'choices'         => decree_custom_section_types(),
	'label'           => esc_html__( 'Select Content Type', 'decree-pro' ),
	'section'         => 'decree_hero_content',
	'settings'        => 'decree_theme_options[hero_content_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[hero_content_number]', array(
	'default'           => $defaults['hero_content_number'],
	'sanitize_callback' => 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[hero_content_number]' , array(
		'active_callback' => 'decree_is_demo_hero_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Hero Content is changed', 'decree-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
		),
		'label'           => esc_html__( 'No of Hero Content', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_number]',
		'type'            => 'number',
		)
);

$wp_customize->add_setting( 'decree_theme_options[hero_content_enable_title]', array(
		'default'           => $defaults['hero_content_enable_title'],
		'sanitize_callback' => 'decree_sanitize_checkbox',
	) );

$wp_customize->add_control(  'decree_theme_options[hero_content_enable_title]', array(
	'active_callback' => 'decree_is_hero_post_page_category_content_active',
	'label'           => esc_html__( 'Check to Enable Title', 'decree-pro' ),
	'section'         => 'decree_hero_content',
	'settings'        => 'decree_theme_options[hero_content_enable_title]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[hero_content_show]', array(
	'default'           => $defaults['hero_content_show'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[hero_content_show]', array(
	'active_callback' => 'decree_is_hero_post_page_category_content_active',
	'choices'         => decree_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'decree-pro' ),
	'section'         => 'decree_hero_content',
	'settings'        => 'decree_theme_options[hero_content_show]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[hero_content_select_category]', array(
	'sanitize_callback'	=> 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_customize_dropdown_categories_control( $wp_customize, 'decree_hero_content_select_category', array(
	'active_callback' => 'decree_is_hero_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[hero_content_select_category]',
	'section'         => 'decree_hero_content',
	'settings'        => 'decree_theme_options[hero_content_select_category]',
	'type'            => 'dropdown-categories',
) ) );

for ( $i=1; $i <= $options['hero_content_number'] ; $i++ ) {

	//post content
	$wp_customize->add_setting( 'decree_theme_options[hero_content_post_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_hero_content_post_'. $i, array(
		'active_callback' => 'decree_is_hero_post_content_active',
		'input_attrs'     => array( 'style' => 'width: 100px;'),
		'label'           => esc_html__( 'Post', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_post_' . $i . ']',
		'type'            => 'text',
	) );

	//page content
	$wp_customize->add_setting( 'decree_theme_options[hero_content_page_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_page',
	) );

	$wp_customize->add_control( 'decree_hero_content_page_'. $i, array(
		'active_callback' => 'decree_is_hero_page_content_active',
		'label'           => esc_html__( 'Page', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_page_' . $i . ']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'decree_theme_options[hero_content_note_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new decree_note_control( $wp_customize, 'hero_content_note_'. $i, array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Hero Content #', 'decree-pro' ) .  $i,
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_note_' . $i . ']',
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[hero_content_title_' . $i . ']', array(
			'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_title_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Title', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_title_' . $i . ']',
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[hero_content_content_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[hero_content_content_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Content', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_content_' . $i . ']',
		'type'            => 'textarea',
	) );

     $wp_customize->add_setting( 'decree_theme_options[hero_content_button_text_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_button_text_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Text', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_button_text_' . $i . ']',
	) );

    $wp_customize->add_setting( 'decree_theme_options[hero_content_button_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_button_link_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Link', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_button_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[hero_content_button_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_button_target_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Button Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_button_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[hero_content_image_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'hero_content_image_'. $i , array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_image_' . $i . ']',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[hero_content_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_link_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image Link', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[hero_content_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[hero_content_target_' . $i . ']', array(
		'active_callback' => 'decree_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_hero_content',
		'settings'        => 'decree_theme_options[hero_content_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );
}
