<?php
/**
* The template for adding Portfolio in Customizer
*
 * @package Decree Pro
*/
// Portfolio Options

$wp_customize->add_section( 'decree_portfolio', array(
	'panel' => 'decree_theme_options',
	'title' => esc_html__( 'Portfolio', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_option]', array(
	'default'			=> $defaults['portfolio_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_option]', array(
	'choices'  	=> decree_section_visibility_options(),
	'label'    	=> esc_html__( 'Enable Portfolio on', 'decree-pro' ),
	'priority'	=> '1',
	'section'  	=> 'decree_portfolio',
	'settings' 	=> 'decree_theme_options[portfolio_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_layout]', array(
	'default'			=> $defaults['portfolio_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_layout]', array(
	'active_callback' => 'decree_is_portfolio_active',
	'choices'         => decree_featured_content_layout_options(),
	'label'           => esc_html__( 'Select Featured Content Layout', 'decree-pro' ),
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_layout]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_type]', array(
	'default'			=> $defaults['portfolio_type'],
	'sanitize_callback'	=> 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_type]', array(
	'active_callback' => 'decree_is_portfolio_active',
	'description'     => sprintf( 'For Custom Post Type Content, either install %1$sEssential Content Types%2$s Plugin or %3$sJetpack%2$s Plugin with %4$Portfolio Content Type%2$s Enabled',
		'<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
		'</a>',
		'<a target="_blank" href="https://wordpress.org/plugins/jetpack/">',
		'<a target="_blank" href="https://en.support.wordpress.com/portfolio/">'
		 ),
	'choices'         => decree_portfolio_types(),
	'label'           => esc_html__( 'Select Content Type', 'decree-pro' ),
	'priority'        => '3',
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_headline]', array(
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_headline]' , array(
	'active_callback' => 'decree_is_demo_portfolio_inactive',
	'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'           => esc_html__( 'Headline for Portfolio', 'decree-pro' ),
	'priority'        => '4',
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_headline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[portfolio_subheadline]', array(
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_subheadline]' , array(
	'active_callback' => 'decree_is_demo_portfolio_inactive',
	'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'           => esc_html__( 'Sub-headline for Portfolio', 'decree-pro' ),
	'priority'        => '5',
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_subheadline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[portfolio_show]', array(
	'default'			=> $defaults['portfolio_show'],
	'sanitize_callback'	=> 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_show]', array(
	'active_callback' => 'decree_is_demo_portfolio_inactive',
	'choices'         => decree_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'decree-pro' ),
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_show]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_number]', array(
	'default'			=> $defaults['portfolio_number'],
	'sanitize_callback'	=> 'decree_sanitize_number_range',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'decree_theme_options[portfolio_number]' , array(
		'active_callback' => 'decree_is_demo_portfolio_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Portfolio is changed', 'decree-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 1,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Portfolio', 'decree-pro' ),
		'priority'        => '6',
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_number]',
		'type'            => 'number',
	)
);

$wp_customize->add_setting( 'decree_theme_options[portfolio_select_category]', array(
	'sanitize_callback'	=> 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_Customize_Dropdown_Categories_Control( $wp_customize, 'decree_portfolio_select_category', array(
	'active_callback' => 'decree_is_portfolio_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[portfolio_select_category]',
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_select_category]',
	'type'            => 'dropdown-categories',
) ) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_hide_category]', array(
    'sanitize_callback'	=> 'decree_sanitize_checkbox',
) );

$wp_customize->add_control(  'decree_theme_options[portfolio_hide_category]', array(
	'active_callback' => 'decree_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Category Meta', 'decree-pro' ),
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_hide_category]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_hide_tags]', array(
    'sanitize_callback'	=> 'decree_sanitize_checkbox',
) );

$wp_customize->add_control(  'decree_theme_options[portfolio_hide_tags]', array(
	'active_callback' => 'decree_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Tag Meta', 'decree-pro' ),
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_hide_tags]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[portfolio_hide_date]', array(
    'sanitize_callback'	=> 'decree_sanitize_checkbox',
) );

$wp_customize->add_control(  'decree_theme_options[portfolio_hide_date]', array(
	'active_callback' => 'decree_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Posted On Date', 'decree-pro' ),
	'section'         => 'decree_portfolio',
	'settings'        => 'decree_theme_options[portfolio_hide_date]',
	'type'            => 'checkbox',
) );

if( is_multi_author() ) {
    $wp_customize->add_setting( 'decree_theme_options[portfolio_hide_author]', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[portfolio_hide_author]', array(
		'active_callback' => 'decree_is_post_category_portfolio_inactive',
		'label'           => esc_html__( 'Check to Hide Author Meta', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_hide_author]',
		'type'            => 'checkbox',
    ) );
}


//loop for content types
for ( $i=1; $i <= $options['portfolio_number'] ; $i++ ) {

	//Post Content
	$wp_customize->add_setting( 'decree_theme_options[portfolio_post_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_theme_options[portfolio_post_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_post_content_active',
		'input_attrs'     => array(
			'style' => 'width: 200px;'
		),
		'label'           => esc_html__( 'Post', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_post_' . $i . ']',
		'type'            => 'text',
		)
	);

	//for CPT
	$wp_customize->add_setting( 'decree_theme_options[portfolio_cpt_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_theme_options[portfolio_cpt_' . $i . ']'. $i, array(
		'active_callback' => 'decree_is_jetpack_portfolio_active',
		'label'           => esc_html__( 'Portfolio ', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_cpt_' . $i . ']',
		'type'            => 'select',
		'choices'         => decree_generate_post_array( 'jetpack-portfolio' ),
		)
	);

	//Page Content
	$wp_customize->add_setting( 'decree_theme_options[portfolio_page_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_page',
	) );

	$wp_customize->add_control( 'decree_theme_options[portfolio_page_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_page_content_active',
		'label'           => esc_html__( 'Page', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_page_' . $i . ']',
		'type'            => 'dropdown-pages',
	) );

	//Image Content
	$wp_customize->add_setting( 'decree_theme_options[portfolio_note_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new decree_Note_Control( $wp_customize, 'decree_theme_options[portfolio_note_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Portfolio #', 'decree-pro' ) .  $i,
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_note_' . $i . ']',
		'type'            => 'description',
		) ) );

	$wp_customize->add_setting( 'decree_theme_options[portfolio_image_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'decree_theme_options[portfolio_image_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Image', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_image_' . $i . ']',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[portfolio_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[portfolio_link_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Link', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[portfolio_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[portfolio_target_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[portfolio_title_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[portfolio_title_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Title', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_title_' . $i . ']',
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[portfolio_content_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[portfolio_content_' . $i . ']', array(
			'active_callback' => 'decree_is_portfolio_image_content_active',
			'label'           => esc_html__( 'Content', 'decree-pro' ),
			'section'         => 'decree_portfolio',
			'settings'        => 'decree_theme_options[portfolio_content_' . $i . ']',
			'type'            => 'textarea',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[portfolio_button_text_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[portfolio_button_text_' . $i . ']', array(
			'active_callback' => 'decree_is_portfolio_image_content_active',
			'label'           => esc_html__( 'Button Text', 'decree-pro' ),
			'section'         => 'decree_portfolio',
			'settings'        => 'decree_theme_options[portfolio_button_text_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[portfolio_button_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control( 'decree_theme_options[portfolio_button_link_' . $i . ']', array(
			'active_callback' => 'decree_is_portfolio_image_content_active',
			'label'           => esc_html__( 'Button Link', 'decree-pro' ),
			'section'         => 'decree_portfolio',
			'settings'        => 'decree_theme_options[portfolio_button_link_' . $i . ']',
	) );


	$wp_customize->add_setting( 'decree_theme_options[portfolio_button_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[portfolio_button_target_' . $i . ']', array(
		'active_callback' => 'decree_is_portfolio_image_content_active',
		'label'           => esc_html__( 'Check to Open Button Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_portfolio',
		'settings'        => 'decree_theme_options[portfolio_button_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );

    //Embed Content
    $wp_customize->add_setting( 'decree_theme_options[portfolio_embed_' . $i . ']', array(
			'sanitize_callback'	=> 'wp_kses_stripslashes',
	) );

	$wp_customize->add_control( 'decree_theme_options[portfolio_embed_' . $i . ']', array(
			'active_callback' => 'decree_is_portfolio_embed_content_active',
			'label'           => esc_html__( 'Embed Content', 'decree-pro' ) . ' ' . $i ,
			'section'         => 'decree_portfolio',
			'settings'        => 'decree_theme_options[portfolio_embed_' . $i . ']',
			'type'            => 'textarea',
    ) );
}
