<?php
/**
* The template for adding Testimonial Settings in Customizer
*
 * @package Decree Pro
*/


$wp_customize->add_section( 'decree_testimonial', array(
	'panel'    => 'decree_theme_options',
	'title'    => esc_html__( 'Testimonial', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_option]', array(
	'default'			=> $defaults['testimonial_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_option]', array(
	'choices'  => decree_section_visibility_options(),
	'label'    => esc_html__( 'Enable on', 'decree-pro' ),
	'section'  => 'decree_testimonial',
	'settings' => 'decree_theme_options[testimonial_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_layout]', array(
	'default'			=> $defaults['testimonial_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_layout]', array(
	'active_callback' => 'decree_is_testimonial_active',
	'choices'         => decree_testimonial_layout_options(),
	'label'           => esc_html__( 'Select Testimonial Layout', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_layout]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_position]', array(
	'default'			=> $defaults['testimonial_position'],
	'sanitize_callback' => 'decree_sanitize_checkbox'
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_position]', array(
	'active_callback' => 'decree_is_testimonial_active',
	'label'           => esc_html__( 'Check to Move above Footer', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_position]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_slider]', array(
	'default'           => $defaults['testimonial_slider'],
	'sanitize_callback' => 'decree_sanitize_checkbox'
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_slider]', array(
	'active_callback' => 'decree_is_testimonial_active',
	'label'           => esc_html__( 'Check to Enable Slider', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_slider]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_type]', array(
	'default'           => $defaults['testimonial_type'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_type]', array(
	'active_callback' => 'decree_is_testimonial_active',
	'choices'         => decree_testimonial_types(),
	'description'     => sprintf( 'For Custom Post Type Content, either install %1$sEssential Content Types%2$s Plugin or %3$sJetpack%2$s Plugin with %4$sTestimonial Content Type%2$s Enabled',
		'<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
		'</a>',
		'<a target="_blank" href="https://wordpress.org/plugins/jetpack/">',
		'<a target="_blank" href="https://en.support.wordpress.com/testimonials/">'
		 ),
	'label'           => esc_html__( 'Select Content Type', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_headline]', array(
	'default'           => $defaults['testimonial_headline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_headline]' , array(
	'active_callback' => 'decree_is_demo_testimonial_inactive',
	'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'           => esc_html__( 'Headline for Testimonial', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_headline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[testimonial_subheadline]', array(
	'default'           => $defaults['testimonial_subheadline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_subheadline]' , array(
	'active_callback' => 'decree_is_demo_testimonial_inactive',
	'description'     => esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'           => esc_html__( 'Sub-headline for Testimonial', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_subheadline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[testimonial_number]', array(
	'default'           => $defaults['testimonial_number'],
	'sanitize_callback' => 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_number]' , array(
		'active_callback' => 'decree_is_demo_testimonial_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Testimonial is changed', 'decree-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
		),
		'label'           => esc_html__( 'No of Testimonial', 'decree-pro' ),
		'section'         => 'decree_testimonial',
		'settings'        => 'decree_theme_options[testimonial_number]',
		'type'            => 'number',
		)
);

$wp_customize->add_setting( 'decree_theme_options[testimonial_enable_title]', array(
		'default'           => $defaults['testimonial_enable_title'],
		'sanitize_callback' => 'decree_sanitize_checkbox',
	) );

$wp_customize->add_control(  'decree_theme_options[testimonial_enable_title]', array(
	'active_callback' => 'decree_is_demo_testimonial_inactive',
	'label'           => esc_html__( 'Check to Enable Title', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_enable_title]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_show]', array(
	'default'           => $defaults['testimonial_show'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[testimonial_show]', array(
	'active_callback' => 'decree_is_post_page_category_cpt_testimonial_active',
	'choices'         => decree_testimonial_content_show(),
	'label'           => esc_html__( 'Display Content', 'decree-pro' ),
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_show]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[testimonial_select_category]', array(
	'sanitize_callback'	=> 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_customize_dropdown_categories_control( $wp_customize, 'decree_testimonial_select_category', array(
	'active_callback' => 'decree_is_category_testimonial_active',
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[testimonial_select_category]',
	'section'         => 'decree_testimonial',
	'settings'        => 'decree_theme_options[testimonial_select_category]',
	'type'            => 'dropdown-categories',
) ) );

for ( $i=1; $i <= $options['testimonial_number'] ; $i++ ) {
	//for featured post content
	$wp_customize->add_setting( 'decree_theme_options[testimonial_post_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_theme_options[testimonial_post_' . $i . ']', array(
		'active_callback' => 'decree_is_post_testimonial_active',
		'input_attrs'     => array(
			'style' => 'width: 100px;'
		),
		'label'    	      => esc_html__( 'Post', 'decree-pro' ) . ' ' . $i ,
		'section'  	      => 'decree_testimonial',
		'settings' 	      => 'decree_theme_options[testimonial_post_' . $i . ']',
		)
	);

	//for CPT
	$wp_customize->add_setting( 'decree_theme_options[testimonial_cpt_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_theme_options[testimonial_cpt_' . $i . ']'. $i, array(
		'active_callback' => 'decree_is_jetpack_testimonial_active',
		'label'           => esc_html__( 'Testimonial ', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_testimonial',
		'settings'        => 'decree_theme_options[testimonial_cpt_' . $i . ']',
		'type'            => 'select',
		'choices'         => decree_generate_post_array( 'jetpack-testimonial' ),
		)
	);

	$wp_customize->add_setting( 'decree_theme_options[testimonial_page_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_page',
	) );

	$wp_customize->add_control( 'decree_testimonial_page_'. $i, array(
		'active_callback' => 'decree_is_page_testimonial_active',
		'label'           => esc_html__( 'Page', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_testimonial',
		'settings'        => 'decree_theme_options[testimonial_page_' . $i . ']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_note_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new decree_note_control( $wp_customize, 'testimonial_note_'. $i, array(
		'active_callback' => 'decree_is_image_testimonial_active',
		'label'           => esc_html__( 'Testimonial #', 'decree-pro' ) .  $i,
		'section'         => 'decree_testimonial',
		'settings'        => 'decree_theme_options[testimonial_note_' . $i . ']',
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_image_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'testimonial_image_'. $i , array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Image', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_image_' . $i . ']',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[testimonial_link_' . $i . ']', array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Link', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_target_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[testimonial_target_' . $i . ']', array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_target_' . $i . ']',
		'type'		=> 'checkbox',
	) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_content_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[testimonial_content_' . $i . ']', array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Testimonial Text', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_content_' . $i . ']',
		'type'		=> 'textarea',
	) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_title_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[testimonial_title_' . $i . ']', array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Name', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_title_' . $i . ']',
		'type'		=> 'text',
	) );

	$wp_customize->add_setting( 'decree_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[testimonial_position_' . $i . ']', array(
		'active_callback'	=> 'decree_is_image_testimonial_active',
		'label'		=> esc_html__( 'Position', 'decree-pro' ),
		'section'   => 'decree_testimonial',
		'settings'  => 'decree_theme_options[testimonial_position_' . $i . ']',
		'type'		=> 'text',
	) );
} // End for().
