<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package Decree Pro
 */
?>

<?php
/**
 * decree_before_secondary hook
 *
 * @hooked decree_after_posts_pages_sidebar - 10
 * @hooked decree_main_end - 20
 * @hooked decree_primary_end - 30
 *
 */

do_action( 'decree_before_secondary' );

$decree_layout = decree_get_theme_layout();

// Bail early if no sidebar layout is selected.
if ( 'no-sidebar' === $decree_layout || 'no-sidebar-one-column' === $decree_layout || 'no-sidebar-full-width' === $decree_layout ) {
	return;
}


// WooCommerce Shop Page excluding Cart and checkout.
if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
	$shop_id = get_option( 'woocommerce_shop_page_id' );
	$sidebaroptions = get_post_meta( $shop_id, 'decree-sidebar-options', true );
} else {
	global $post, $wp_query;

	// Front page displays in Reading Settings.
	$page_on_front = (int) get_option('page_on_front');;
	$page_for_posts = (int) get_option( 'page_for_posts' );

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Blog Page or Front Page setting in Reading Settings
	if ( $page_id === $page_for_posts || $page_id === $page_on_front ) {
		$sidebaroptions = get_post_meta( $page_id, 'decree-sidebar-options', true );
	}
	else if ( is_singular() ) {
		if ( is_attachment() ) {
			$parent 		= $post->post_parent;
			$sidebaroptions = get_post_meta( $parent, 'decree-sidebar-options', true );

		}
		else {
			$sidebaroptions = get_post_meta( $post->ID, 'decree-sidebar-options', true );
		}
	}
	else {
		$sidebaroptions = '';
	}
}

/**
 * decree_before_primary_sidebar hook
 */
do_action( 'decree_before_primary_sidebar' );
?>
	<aside class="sidebar sidebar-primary widget-area" role="complementary">
		<?php
		if ( is_active_sidebar( 'sidebar-optional-woocommmerce' ) && class_exists( 'WooCommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
			dynamic_sidebar( 'sidebar-optional-woocommmerce' );
		}
		elseif ( is_active_sidebar( 'sidebar-optional-one' ) && 'optional-sidebar-one' === $sidebaroptions  ) {
			dynamic_sidebar( 'sidebar-optional-one' );
		}
		elseif ( is_active_sidebar( 'sidebar-optional-two' ) && 'optional-sidebar-two' === $sidebaroptions  ) {
			dynamic_sidebar( 'sidebar-optional-two' );
		}
		elseif ( is_active_sidebar( 'sidebar-optional-three' ) && 'optional-sidebar-three' === $sidebaroptions  ) {
			dynamic_sidebar( 'sidebar-optional-three' );
		}
		elseif ( is_active_sidebar( 'sidebar-optional-homepage' ) && ( is_front_page() || ( is_home() && $page_id !== $page_for_posts ) ) ) {
			dynamic_sidebar( 'sidebar-optional-homepage' );
		}
		elseif ( is_active_sidebar( 'sidebar-optional-archive' ) && ( is_archive() || ( is_home() && $page_id !== $page_for_posts ) ) ) {
			dynamic_sidebar( 'sidebar-optional-archive' );
		}
		elseif ( is_page() && is_active_sidebar( 'sidebar-optional-page' ) ) {
			dynamic_sidebar( 'sidebar-optional-page' );
		}
		elseif ( is_single() && is_active_sidebar( 'sidebar-optional-post' ) ) {
			dynamic_sidebar( 'sidebar-optional-post' );
		}
		elseif ( is_active_sidebar( 'primary-sidebar' ) ) {
			dynamic_sidebar( 'primary-sidebar' );
		}
		else {
			//Helper Text
			if ( current_user_can( 'edit_theme_options' ) ) { ?>
				<section id="widget-default-text" class="widget widget_text">
					<div class="widget-wrap">
						<h4 class="widget-title"><?php esc_html_e( 'Primary Sidebar Widget Area', 'decree-pro' ); ?></h4>

						<div class="textwidget">
							<p><?php _e( 'This is the Primary Sidebar Widget Area if you are using a two or three column site layout option.', 'decree-pro' ); ?></p>
							<p><?php printf( wp_kses( __( 'By default it will load Search and Archives widgets as shown below. You can add widget to this area by visiting your <a href="%1$s">Widgets Panel</a> which will replace default widgets.', 'decree-pro' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( admin_url( 'widgets.php' ) ) ); ?></p>
						</div><!-- .textwidget -->
					</div><!-- .widget-wrap -->
				</section><!-- #widget-default-text -->
			<?php
			} ?>
			<section class="widget widget_widget_decree_adspace_widget" id="header-right-ads">
				<div class="widget-wrap">
					<a class="ads-image" href="#">
						<img src="<?php echo trailingslashit( esc_url( get_template_directory_uri() ) ); ?>images/ads-300x250.jpg">
					</a>
				</div><!-- .widget-wrap -->
			</section><!-- .widget-wrap -->
			<section class="widget widget_search" id="default-search">
				<div class="widget-wrap">
					<h4 class="widget-title"><?php esc_html_e( 'Search', 'decree-pro' ); ?></h4>
					<?php get_search_form(); ?>
				</div><!-- .widget-wrap -->
			</section><!-- #default-search -->
			<section class="widget widget_archive" id="default-archives">
				<div class="widget-wrap">
					<h4 class="widget-title"><?php esc_html_e( 'Archives', 'decree-pro' ); ?></h4>
					<ul>
						<?php wp_get_archives( array( 'type' => 'monthly' ) ); ?>
					</ul>
				</div><!-- .widget-wrap -->
			</section><!-- #default-archives -->
			<?php
		} ?>
	</aside><!-- .sidebar sidebar-primary widget-area -->
<?php
/**
 * decree_after_primary_sidebar hook
 */
do_action( 'decree_after_primary_sidebar' );


/**
 * decree_after_secondary hook
 *
 */
do_action( 'decree_after_secondary' );
